Index: test/cctest/test-disasm-ia32.cc |
diff --git a/test/cctest/test-disasm-ia32.cc b/test/cctest/test-disasm-ia32.cc |
index b563f8fce49ef994138b0b4bcb04084844da7c3b..30d708e4086dbae82f0c10eba4859980f0224c30 100644 |
--- a/test/cctest/test-disasm-ia32.cc |
+++ b/test/cctest/test-disasm-ia32.cc |
@@ -416,7 +416,7 @@ TEST(DisasmIa320) { |
} |
} |
// andpd, cmpltsd, movaps, psllq. |
{ |
if (CpuFeatures::IsSupported(SSE2)) { |
CpuFeatures::Scope fscope(SSE2); |
@@ -431,6 +431,18 @@ TEST(DisasmIa320) { |
__ psllq(xmm0, 17); |
__ psllq(xmm1, 42); |
+ |
+ __ psllq(xmm0, xmm1); |
+ __ psllq(xmm1, xmm2); |
+ |
+ __ psrlq(xmm0, 17); |
+ __ psrlq(xmm1, 42); |
+ |
+ __ psrlq(xmm0, xmm1); |
+ __ psrlq(xmm1, xmm2); |
+ |
+ __ por(xmm0, xmm1); |
+ __ por(xmm1, xmm2); |
} |
} |
@@ -416,7 +416,7 @@ TEST(DisasmIa320) { |
} |
} |
- // andpd, cmpltsd, movaps, psllq. |
+ // andpd, cmpltsd, movaps, psllq, psrlq, por. |
{ |
if (CpuFeatures::IsSupported(SSE2)) { |